Package 'xlsformr'

Title: Creating XLSForms for Open Data Kit Using R
Description: Open Data Kit (ODK) uses a low-level form specification based on XForms. However, XForms can still prove challenging to use for creating forms. XLSForm, a high-level spreadsheet-based form specification, has been developed to facilitate creation of ODK forms for majority of users as it uses a tool that is familiar with most. This package provides functions to create an XLSForm using R.
Authors: Ernest Guevarra [aut, cre] (ORCID: <https://orcid.org/0000-0002-4887-4415>)
Maintainer: Ernest Guevarra <[email protected]>
License: MIT + file LICENSE
Version: 0.1.0
Built: 2026-05-23 08:07:17 UTC
Source: https://github.com/rapidsurveys/xlsformr

Help Index